@@ -65,7 +65,13 @@ if path_to_trna !='':
         os.chdir(cwd)
     except:
         os.chdir(cwd)   
+        
+        
     
+try: 
+    import ssa_translation_lowmem
+except:
+    pass
 
 class ModelBuilder():
     '''
